==> ejc-middlemeasurement-impl-3.0.0-20220412.090131-33-sources.jar: com/ejianc/business/middlemeasurement/bean/RevolvingleasesummarydetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 月度周转工具租赁费结算汇总子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_revolvingleasesummarydetail")
public class RevolvingleasesummarydetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="category_name")
    private java.lang.String categoryName; // 设备类别/名称
    @TableField(value="lessee_id")
    private java.lang.Long lesseeId; // 租赁商id
    @TableField(value="lessee_name")
    private java.lang.String lesseeName; // 租赁商名称
    @TableField(value="settle_account")
    private java.math.BigDecimal settleAccount; // 本月结算金额(除税)
    @TableField(value="tax_settle_account")
    private java.math.BigDecimal taxSettleAccount; // 本月结算金额(含税)
    @TableField(value="cumulative_amount")
    private java.math.BigDecimal cumulativeAmount; // 累计结算金额(含税)
    @TableField(value="tax_cumulative_amount")
    private java.math.BigDecimal taxCumulativeAmount; // 累计结算金额(含税)
    @TableField(value="payment_proportion")
    private java.math.BigDecimal paymentProportion; // 合同付款比例
    @TableField(value="cumulative_payable")
    private java.math.BigDecimal cumulativePayable; // 至本月累计应付款金额
    @TableField(value="cumulative_payment")
    private java.math.BigDecimal cumulativePayment; // 至本月累计付款金额
    @TableField(value="contacts")
    private java.lang.String contacts; // 联系人
    @TableField(value="contacts_way")
    private java.lang.String contactsWay; // 联系方式
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="material_code")
    private java.lang.String materialCode; // 物资编号
    
    
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 设备类别/名称
     */
    public java.lang.String getCategoryName() {
        return categoryName;
    }

    /**
     * 设备类别/名称
     */
    public void setCategoryName(java.lang.String categoryName) {
        this.categoryName = categoryName;
    }
    /**
     * 租赁商id
     */
    public java.lang.Long getLesseeId() {
        return lesseeId;
    }

    /**
     * 租赁商id
     */
    public void setLesseeId(java.lang.Long lesseeId) {
        this.lesseeId = lesseeId;
    }

    public String getLesseeName() {
        return lesseeName;
    }

    public void setLesseeName(String lesseeName) {
        this.lesseeName = lesseeName;
    }

    /**
     * 本月结算金额(除税)
     */
    public java.math.BigDecimal getSettleAccount() {
        return settleAccount;
    }

    /**
     * 本月结算金额(除税)
     */
    public void setSettleAccount(java.math.BigDecimal settleAccount) {
        this.settleAccount = settleAccount;
    }
    /**
     * 本月结算金额(含税)
     */
    public java.math.BigDecimal getTaxSettleAccount() {
        return taxSettleAccount;
    }

    /**
     * 本月结算金额(含税)
     */
    public void setTaxSettleAccount(java.math.BigDecimal taxSettleAccount) {
        this.taxSettleAccount = taxSettleAccount;
    }
    /**
     * 累计结算金额(含税)
     */
    public java.math.BigDecimal getCumulativeAmount() {
        return cumulativeAmount;
    }

    /**
     * 累计结算金额(含税)
     */
    public void setCumulativeAmount(java.math.BigDecimal cumulativeAmount) {
        this.cumulativeAmount = cumulativeAmount;
    }
    /**
     * 累计结算金额(含税)
     */
    public java.math.BigDecimal getTaxCumulativeAmount() {
        return taxCumulativeAmount;
    }

    /**
     * 累计结算金额(含税)
     */
    public void setTaxCumulativeAmount(java.math.BigDecimal taxCumulativeAmount) {
        this.taxCumulativeAmount = taxCumulativeAmount;
    }
    /**
     * 合同付款比例
     */
    public java.math.BigDecimal getPaymentProportion() {
        return paymentProportion;
    }

    /**
     * 合同付款比例
     */
    public void setPaymentProportion(java.math.BigDecimal paymentProportion) {
        this.paymentProportion = paymentProportion;
    }
    /**
     * 至本月累计应付款金额
     */
    public java.math.BigDecimal getCumulativePayable() {
        return cumulativePayable;
    }

    /**
     * 至本月累计应付款金额
     */
    public void setCumulativePayable(java.math.BigDecimal cumulativePayable) {
        this.cumulativePayable = cumulativePayable;
    }
    /**
     * 至本月累计付款金额
     */
    public java.math.BigDecimal getCumulativePayment() {
        return cumulativePayment;
    }

    /**
     * 至本月累计付款金额
     */
    public void setCumulativePayment(java.math.BigDecimal cumulativePayment) {
        this.cumulativePayment = cumulativePayment;
    }
    /**
     * 联系人
     */
    public java.lang.String getContacts() {
        return contacts;
    }

    /**
     * 联系人
     */
    public void setContacts(java.lang.String contacts) {
        this.contacts = contacts;
    }
    /**
     * 联系方式
     */
    public java.lang.String getContactsWay() {
        return contactsWay;
    }

    /**
     * 联系方式
     */
    public void setContactsWay(java.lang.String contactsWay) {
        this.contactsWay = contactsWay;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
}

==> ejc-middlemeasurement-impl-3.0.0-20221014.034307-161-sources.jar: com/ejianc/business/middlemeasurement/bean/RevolvingleasesummarydetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 月度周转工具租赁费结算汇总子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_revolvingleasesummarydetail")
public class RevolvingleasesummarydetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="category_name")
    private java.lang.String categoryName; // 设备类别/名称
    @TableField(value="lessee_id")
    private java.lang.Long lesseeId; // 租赁商id
    @TableField(value="lessee_name")
    private java.lang.String lesseeName; // 租赁商名称
    @TableField(value="settle_account")
    private java.math.BigDecimal settleAccount; // 本月结算金额(除税)
    @TableField(value="tax_settle_account")
    private java.math.BigDecimal taxSettleAccount; // 本月结算金额(含税)
    @TableField(value="cumulative_amount")
    private java.math.BigDecimal cumulativeAmount; // 累计结算金额(含税)
    @TableField(value="tax_cumulative_amount")
    private java.math.BigDecimal taxCumulativeAmount; // 累计结算金额(含税)
    @TableField(value="payment_proportion")
    private java.math.BigDecimal paymentProportion; // 合同付款比例
    @TableField(value="cumulative_payable")
    private java.math.BigDecimal cumulativePayable; // 至本月累计应付款金额
    @TableField(value="cumulative_payment")
    private java.math.BigDecimal cumulativePayment; // 至本月累计付款金额
    @TableField(value="contacts")
    private java.lang.String contacts; // 联系人
    @TableField(value="contacts_way")
    private java.lang.String contactsWay; // 联系方式
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="material_code")
    private java.lang.String materialCode; // 物资编号
    @TableField(value="material_category_code")
    private java.lang.String materialCategoryCode; // 物资分类编码
    
    
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 设备类别/名称
     */
    public java.lang.String getCategoryName() {
        return categoryName;
    }

    /**
     * 设备类别/名称
     */
    public void setCategoryName(java.lang.String categoryName) {
        this.categoryName = categoryName;
    }
    /**
     * 租赁商id
     */
    public java.lang.Long getLesseeId() {
        return lesseeId;
    }

    /**
     * 租赁商id
     */
    public void setLesseeId(java.lang.Long lesseeId) {
        this.lesseeId = lesseeId;
    }

    public String getLesseeName() {
        return lesseeName;
    }

    public void setLesseeName(String lesseeName) {
        this.lesseeName = lesseeName;
    }

    /**
     * 本月结算金额(除税)
     */
    public java.math.BigDecimal getSettleAccount() {
        return settleAccount;
    }

    /**
     * 本月结算金额(除税)
     */
    public void setSettleAccount(java.math.BigDecimal settleAccount) {
        this.settleAccount = settleAccount;
    }
    /**
     * 本月结算金额(含税)
     */
    public java.math.BigDecimal getTaxSettleAccount() {
        return taxSettleAccount;
    }

    /**
     * 本月结算金额(含税)
     */
    public void setTaxSettleAccount(java.math.BigDecimal taxSettleAccount) {
        this.taxSettleAccount = taxSettleAccount;
    }
    /**
     * 累计结算金额(含税)
     */
    public java.math.BigDecimal getCumulativeAmount() {
        return cumulativeAmount;
    }

    /**
     * 累计结算金额(含税)
     */
    public void setCumulativeAmount(java.math.BigDecimal cumulativeAmount) {
        this.cumulativeAmount = cumulativeAmount;
    }
    /**
     * 累计结算金额(含税)
     */
    public java.math.BigDecimal getTaxCumulativeAmount() {
        return taxCumulativeAmount;
    }

    /**
     * 累计结算金额(含税)
     */
    public void setTaxCumulativeAmount(java.math.BigDecimal taxCumulativeAmount) {
        this.taxCumulativeAmount = taxCumulativeAmount;
    }
    /**
     * 合同付款比例
     */
    public java.math.BigDecimal getPaymentProportion() {
        return paymentProportion;
    }

    /**
     * 合同付款比例
     */
    public void setPaymentProportion(java.math.BigDecimal paymentProportion) {
        this.paymentProportion = paymentProportion;
    }
    /**
     * 至本月累计应付款金额
     */
    public java.math.BigDecimal getCumulativePayable() {
        return cumulativePayable;
    }

    /**
     * 至本月累计应付款金额
     */
    public void setCumulativePayable(java.math.BigDecimal cumulativePayable) {
        this.cumulativePayable = cumulativePayable;
    }
    /**
     * 至本月累计付款金额
     */
    public java.math.BigDecimal getCumulativePayment() {
        return cumulativePayment;
    }

    /**
     * 至本月累计付款金额
     */
    public void setCumulativePayment(java.math.BigDecimal cumulativePayment) {
        this.cumulativePayment = cumulativePayment;
    }
    /**
     * 联系人
     */
    public java.lang.String getContacts() {
        return contacts;
    }

    /**
     * 联系人
     */
    public void setContacts(java.lang.String contacts) {
        this.contacts = contacts;
    }
    /**
     * 联系方式
     */
    public java.lang.String getContactsWay() {
        return contactsWay;
    }

    /**
     * 联系方式
     */
    public void setContactsWay(java.lang.String contactsWay) {
        this.contactsWay = contactsWay;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialCategoryCode() {
        return materialCategoryCode;
    }

    public void setMaterialCategoryCode(String materialCategoryCode) {
        this.materialCategoryCode = materialCategoryCode;
    }
}
